@@ -7,7 +7,7 @@ from enum import Enum
 class Queue(str, Enum):
     integrations = "integrations"
     scouty = "scouty"
-    feedmanager = "feedmanager"
+    jobs = "jobs"
     insights = "insights"
     billing = "billing"
 
